<!DOCTYPE html>
<html lang="en">

<!-- Mirrored from seoc-html-v2.vercel.app/index12.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:40:31 GMT -->
<!-- Added by HTTrack --><meta http-equiv="content-type" content="text/html;charset=utf-8" /><!-- /Added by HTTrack -->
<head>
     <meta charset="UTF-8">
     <meta name="viewport" content="width=device-width, initial-scale=1.0">
     <title>SEOC - Digital Marketing Agency</title>

     <!--=====FAB ICON=======-->
    <link rel="shortcut icon" href="assets/img/logo/fav-logo10.png" type="image/x-icon">

    <!--===== CSS LINK =======-->
    <link rel="stylesheet" href="assets/css/plugins/bootstrap.min.css">
    <link rel="stylesheet" href="assets/css/plugins/aos.css">
    <link rel="stylesheet" href="assets/css/plugins/fontawesome.css">
    <link rel="stylesheet" href="assets/css/plugins/magnific-popup.css">
    <link rel="stylesheet" href="assets/css/plugins/mobile.css">
    <link rel="stylesheet" href="assets/css/plugins/owlcarousel.min.css">
    <link rel="stylesheet" href="assets/css/plugins/sidebar.css">
    <link rel="stylesheet" href="assets/css/plugins/slick-slider.css">
    <link rel="stylesheet" href="assets/css/plugins/nice-select.css">
    <link rel="stylesheet" href="assets/css/main.css">

    <!--=====  JS SCRIPT LINK =======-->
    <script src="assets/js/plugins/jquery-3-6-0.min.js"></script>
</head>
<body class="homepage12-body">

<!--===== PRELOADER STARTS =======-->
<div class="preloader preloader12">
  <div class="loading-container">
    <div class="loading"></div>
    <div id="loading-icon"><img src="assets/img/logo/preloader10.png" alt=""></div>
  </div>
</div>
<!--===== PRELOADER ENDS =======-->

<!--===== PROGRESS STARTS=======-->
<div class="paginacontainer">
     <div class="progress-wrap">
       <svg class="progress-circle svg-content" width="100%" height="100%" viewBox="-1 -1 102 102">
         <path d="M50,1 a49,49 0 0,1 0,98 a49,49 0 0,1 0,-98"/>
       </svg>
     </div>
   </div>
 <!--===== PROGRESS ENDS=======-->

   <!--=====HEADER START=======-->
   <header class="homepage12-body">
    <div class="header-area homepage12 header header-sticky d-none d-lg-block " id="header">
      <div class="container">
        <div class="row">
          <div class="col-lg-12">
            <div class="header-elements">
              <div class="site-logo">
                <a href="index.html"><img src="assets/img/logo/logo13.png" alt=""></a>
              </div>
              <div class="main-menu">
                <ul>
                  <li><a href="#">Home <i class="fa-solid fa-angle-down"></i></a>
                    <div class="tp-submenu">
                      <div class="row">
                         <div class="col-lg-12">
                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img1.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn20" href="index.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn20" href="single-index1.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="404.html">SEO & Digital Marketing 01</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img2.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn20" href="index2.html" target="_blank"> Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn20" href="single-index2.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index2.html">SEO & Digital Marketing 02</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/comming-soon.png" alt="" class="commingsoon">
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn20" href="index3.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn20" href="single-index3.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index3.html">SEO & Digital Marketing 03</a>
                               </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img3.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn20" href="index4.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn20" href="single-index4.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index4.html">SEO & Digital Marketing 04</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img4.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn20" href="index5.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn20" href="single-index5.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index5.html">SEO & Digital Marketing 05</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>
                          </div>
                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img11.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn20" href="index11.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn20" href="single-index11.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index11.html">Staffing Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img12.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn20" href="index12.html" target="_blank"> Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn20" href="single-index12.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index12.html">Consulting Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img13.png" alt="" class="commingsoon">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn20" href="index13.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn20" href="single-index13.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index13.html">Advertising Agency</a>
                               </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img14.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn20" href="index14.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn20" href="single-index14.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index14.html">IT Solution Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img15.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn20" href="index15.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn20" href="single-index15.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index15.html">Startup Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>
                          </div>
                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img5.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn20" href="index6.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn20" href="single-index6.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index6.html">SEO & Digital Marketing 06</a>
                                 </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img6.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn20" href="index7.html" target="_blank"> Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn20" href="single-index7.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index7.html">SEO & Digital Marketing 07</a>
                                 </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img7.png" alt="" class="commingsoon">
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn20" href="index8.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn20" href="single-index8.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index8.html">SEO & Digital Marketing 08</a>
                               </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img8.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn20" href="index9.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn20" href="single-index9.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index9.html">SEO & Digital Marketing 09</a>
                                 </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img9.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>HOT</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn20" href="index10.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn20" href="single-index10.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index10.html">SEO & Digital Marketing 10</a>
                                 </div>
                              </div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img17.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index6.html">Creative Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img16.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index7.html">Digital Marketing Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img18.png" alt="" class="commingsoon">
                                </div>
                               <div class="homemenu-content">
                                <a href="index8.html">Digital Marketer Agency</a>
                               </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img19.png" alt="">
                                </div>
  
                                 <div class="homemenu-content">
                                  <a href="index9.html">Corporate Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img20.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index10.html">Coming Soon</a>
                                 </div>
                              </div>
                            </div>
                          </div>
                         </div>
                      </div>
                   </div>
                  </li>
                  <li><a href="about.html">About</a></li>
                  <li><a href="#">Services <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="service1.html">Service One</a></li>
                      <li><a href="service2.html">Service Two</a></li>
                      <li><a href="service3.html">Service Three</a></li>
                      <li><a href="service4.html">Service Four</a></li>
                      <li><a href="service5.html">Service Five</a></li>
                    </ul>
                  </li>
                  <li><a href="#">Blogs <i class="fa-solid fa-angle-down"></i></a>
                  <ul class="dropdown-padding">
                    <li><a href="blog.html">Blog One</a></li>
                    <li><a href="blog-left.html">Blog Left</a></li>
                    <li><a href="blog-right.html">Blog Right</a></li>
                    <li><a href="blog-single.html">Blog Single</a></li>
                  </ul>
                  </li>
                  <li><a href="#">Pages <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="case.html">Case Study</a></li>
                      <li><a href="case-single.html">Case Study Single</a></li>
                      <li><a href="team.html">Our Team</a></li>
                      <li><a href="pricing.html">Pricing Plan</a></li>
                      <li><a href="testimonials.html">Testimonials</a></li>
                      <li><a href="faq.html">FAQ</a></li>
                      <li><a href="404-2.html">404</a></li>
                    </ul>
                  </li>
                  <li><a href="contact.html">Contact Us</a></li>
                </ul>
              </div>
              <div class="btn-area">
                <a href="contact.html" class="header-btn20">Get Started <i class="fa-solid fa-angle-right"></i></a>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </header>
  <!--=====HEADER END =======-->

  <!--===== MOBILE HEADER STARTS =======-->
 <div class="mobile-header mobile-haeder12 d-block d-lg-none">
  <div class="container-fluid">
    <div class="col-12">
      <div class="mobile-header-elements">
        <div class="mobile-logo">
          <a href="index.html"><img src="assets/img/logo/logo13.png" alt=""></a>
        </div>
        <div class="mobile-nav-icon dots-menu">
          <i class="fa-solid fa-bars"></i>
        </div>
      </div>
    </div>
  </div>
</div>

<div class="mobile-sidebar mobile-sidebar12">
  <div class="logosicon-area">
    <div class="logos">
      <img src="assets/img/logo/logo13.png" alt="">
    </div>
    <div class="menu-close">
      <i class="fa-solid fa-xmark"></i>
    </div>
   </div>
  <div class="mobile-nav mobile-nav1">
    <ul class="mobile-nav-list nav-list1">
      <li><a href="#" >Home </a>
        <ul class="sub-menu">
          <li>
            <a href="#">Multiple Page</a>
            <ul class="sub-menu">
              <li><a href="index.html">Home One</a></li>
              <li><a href="index2.html">Home Two</a></li>
              <li><a href="index3.html">Home Three</a></li>
              <li><a href="index4.html">Home Four</a></li>
              <li><a href="index5.html">Home Five</a></li>
              <li><a href="index6.html">Home Six</a></li>
              <li><a href="index7.html">Home Seven</a></li>
              <li><a href="index8.html">Home Eight</a></li>
              <li><a href="index9.html">Home Nine</a></li>
              <li><a href="index10.html">Home Ten</a></li>
              <li><a href="index11.html">Home Eleven</a></li>
              <li><a href="index12.html">Home Twelve</a></li>
              <li><a href="index13.html">Home Thirteen</a></li>
              <li><a href="index14.html">Home Fouteen</a></li>
              <li><a href="index15.html">Home Fifteen</a></li>
            </ul>
          </li>
          <li>
            <a href="#">Landing Page</a>
            <ul class="sub-menu">
              <li><a href="single-index1.html" target="_blank">Home One</a></li>
              <li><a href="single-index2.html" target="_blank">Home Two</a></li>
              <li><a href="single-index3.html" target="_blank">Home Three</a></li>
              <li><a href="single-index4.html" target="_blank">Home Four</a></li>
              <li><a href="single-index5.html" target="_blank">Home Five</a></li>
              <li><a href="single-index6.html" target="_blank">Home Six</a></li>
              <li><a href="single-index7.html" target="_blank">Home Seven</a></li>
              <li><a href="single-index8.html" target="_blank">Home Eight</a></li>
              <li><a href="single-index9.html" target="_blank">Home Nine</a></li>
              <li><a href="single-index10.html" target="_blank">Home Ten</a></li>
              <li><a href="single-index11.html" target="_blank">Home Eleven</a></li>
              <li><a href="single-index12.html" target="_blank">Home Twelve</a></li>
              <li><a href="single-index13.html" target="_blank">Home Thirteen</a></li>
              <li><a href="single-index14.html" target="_blank">Home Fouteen</a></li>
              <li><a href="single-index15.html" target="_blank">Home Fifteen</a></li>
            </ul>
          </li>
        </ul>
      </li>
      <li><a href="about.html">About</a></li>
      <li><a href="404-3.html">Services</a>
        <ul class="sub-menu">
          <li><a href="service1.html">Service One</a></li>
          <li><a href="service2.html">Service Two</a></li>
          <li><a href="service3.html">Service Three</a></li>
          <li><a href="service4.html">Service Four</a></li>
          <li><a href="service5.html">Service Five</a></li>
        </ul>
      </li>
      <li><a href="#">Blogs</a>
        <ul class="sub-menu">
          <li><a href="blog.html">Blog One</a></li>
          <li><a href="blog-left.html">Blog Left</a></li>
          <li><a href="blog-right.html">Blog Right</a></li>
          <li><a href="blog-single.html">Blog Single</a></li>
        </ul>
      </li>
      <li><a href="#">Pages</a>
        <ul class="sub-menu">
          <li><a href="case.html">Case Study One</a></li>
          <li><a href="case-single.html">Case Study Single</a></li>
          <li><a href="team.html">Our Team</a></li>
          <li><a href="pricing.html">Pricing Plan</a></li>
          <li><a href="testimonials.html">Testimonials</a></li>
          <li><a href="faq.html">FAQ</a></li>
          <li><a href="404-2.html">404</a></li>
        </ul>
      </li>
      <li><a href="contact.html">Contact Us</a></li>
    </ul>

    <div class="allmobilesection">
      <a href="contact.html"  class="header-btn20">Get Started <span><i class="fa-solid fa-angle-right"></i></span></a>
      <div class="single-footer">
        <h3>Contact Info</h3>
        <div class="footer1-contact-info">
          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-phone-volume"></i>
            </div>
            <div class="contact-info-text">
              <a href="tel:+3(924)4596512">+3(924)4596512</a>
            </div>
          </div>

          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-envelope"></i>
            </div>
            <div class="contact-info-text">
              <a href="mailto:info@example.com">info@example.com</a>
            </div>
          </div>

          <div class="single-footer">
            <h3>Our Location</h3>
            
            <div class="contact-info-single">
              <div class="contact-info-icon">
                <i class="fa-solid fa-location-dot"></i>
              </div>
              <div class="contact-info-text">
                <a href="mailto:info@example.com" >55 East Birchwood Ave.Brooklyn, <br> New York 11201,United States</a>
              </div>
            </div>

          </div>
          <div class="single-footer">
            <h3>Social Links</h3>
            
            <div class="social-links-mobile-menu">
              <ul>
                <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
              </ul>
            </div>
          </div>
        </div>
      </div>
     </div>
  </div>
</div>
<!--===== MOBILE HEADER STARTS =======-->

<!--===== HERO AREA STARTS =======-->
<div class="hero12-section-area">
    <div class="bg1">
        <img src="assets/img/bg/hero-bg1.png" alt="">
    </div>
    <img src="assets/img/bg/hero-bg2.png" alt="" class="hero-bg2 aniamtion-key-2">
    <img src="assets/img/elements/elements26.png" alt="" class="elements26">
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-6">
                <div class="hero-header heading17">
                    <h5><img src="assets/img/icons/logo-icon9.svg" alt=""> Top #1 SEO & Marketing Agency</h5>
                    <div class="space16"></div>
                    <h2>Expert Consulting For Future-Ready Businesses</h2>
                    <div class="space24"></div>
                    <p>We specialize in transforming businesses through innovative <br class="d-lg-block d-none"> strategies and tailored solutions with deep understanding.</p>
                    <div class="space32"></div>
                    <div class="btn-area1">
                        <a href="contact.html" class="header-btn20">Start Ranking Now <i class="fa-solid fa-angle-right"></i></a>
                    </div>
                </div>
            </div>
            <div class="col-lg-2"></div>
            <div class="col-lg-4">
                <div class="hero-images-area">
                    <div class="icons">
                        <img src="assets/img/icons/hero-icon1.svg" alt="" class="icons1 aniamtion-key-1">
                        <img src="assets/img/icons/hero-icon2.svg" alt="" class="icons2 aniamtion-key-4">
                        <img src="assets/img/elements/elements25.png" alt="" class="elements25 aniamtion-key-2">
                    </div>
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/header-img12.png" alt="">
                    </div>
                    <div class="author-img aniamtion-key-5">
                        <img src="assets/img/all-images/new-img/auhtor-img12.png" alt="">
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== HERO AREA ENDS =======-->

<!--===== ABOUT AREA STARTS =======-->
<div class="abut12-section-area sp1">
  <div class="container">
    <div class="row">
      <div class="col-lg-6">
        <div class="about-images-area">
          <div class="img1 image-anime reveal">
            <div class="video">
              <a href="https://www.youtube.com/watch?v=Y8XpQpW5OVY" class="popup-youtube"><i class="fa-solid fa-play"></i></a>
            </div>
            <img src="assets/img/all-images/new-img/about-img1-h12.png" alt="">
          </div>
          <div class="img2 image-anime reveal">
            <img src="assets/img/all-images/new-img/about-img2-h12.png" alt="">
          </div>
        </div>
      </div>
      <div class="col-lg-6">
        <div class="about12-header heading18 space-margin60">
          <h5 data-aos="fade-left" data-aos-duration="800">About Us</h5>
          <div class="space16"></div>
          <h2 class="text-anime-style-3">Driven by Insight, Defined <br class="d-lg-block d-none"> By Excellence</h2>
          <div class="space20"></div>
          <p data-aos="fade-left" data-aos-duration="1000">With years of experience across diverse industries, offer strategic insights, innovative solutions, and hands-on expertise to address.</p>
          <div class="about-boxarea">
            <div class="row">
              <div class="col-lg-6 col-md-6" data-aos="zoom-in" data-aos-duration="900">
                <div class="box1">
                  <div class="icons">
                    <img src="assets/img/icons/service-icon29.svg" alt="">
                  </div>
                  <div class="space16"></div>
                  <a href="team.html">Meet the Experts Behind Your Success</a>
                </div>
              </div>
              <div class="col-lg-6 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                <div class="box1">
                  <div class="icons">
                    <img src="assets/img/icons/service-icon30.svg" alt="">
                  </div>
                  <div class="space16"></div>
                  <a href="team.html">The Team Behind Your Strategic Advantage</a>
                </div>
              </div>
            </div>
          </div>
          <div class="space48"></div>
          <div class="btn-area1" data-aos="zoom-in" data-aos-duration="1200">
            <a href="contact.html" class="header-btn20">Get to Know Us <i class="fa-solid fa-angle-right"></i></a>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== ABOUT AREA ENDS =======-->

<!--===== SERVICE AREA STARTS =======-->
<div class="service12-section-area sp1">
  <div class="container">
    <div class="row">
      <div class="col-lg-12">
        <div class="service-header space-margin60 heading18">
          <h5>Our Service</h5>
          <div class="space16"></div>
          <h2>Comprehensive Consulting</h2>
        </div>
      </div>
    </div>
    <div class="col-lg-12">
      <div class="service-slider owl-carousel">
        <div class="service12-boxarea">
          <div class="icons">
            <img src="assets/img/icons/service-icon29.svg" alt="">
          </div>
          <div class="space20"></div>
          <div class="content">
            <a href="service1.html">Customer Success Strategies</a>
            <div class="space16"></div>
            <p>Our Visionary Strategy service is designed  help businesses chart a clear path success we collaborate closely with to understand.</p>
            <div class="space24"></div>
            <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
          </div>
        </div>

        <div class="service12-boxarea">
          <div class="icons">
            <img src="assets/img/icons/service-icon30.svg" alt="">
          </div>
          <div class="space20"></div>
          <div class="content">
            <a href="service1.html">Strategic Risk Solutions</a>
            <div class="space16"></div>
            <p>Our approach combines industry insights, data-driven analysis, and innovative thinking to develop actionable strategies that drive.</p>
            <div class="space24"></div>
            <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
          </div>
        </div>

        <div class="service12-boxarea">
          <div class="icons">
            <img src="assets/img/icons/service-icon31.svg" alt="">
          </div>
          <div class="space20"></div>
          <div class="content">
            <a href="service1.html">Financial Excellence</a>
            <div class="space16"></div>
            <p>Whether you're looking enter new markets, optimize operations, or set long objectives, our team is dedicated providing guidance</p>
            <div class="space24"></div>
            <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
          </div>
        </div>

        <div class="service12-boxarea">
          <div class="icons">
            <img src="assets/img/icons/service-icon32.svg" alt="">
          </div>
          <div class="space20"></div>
          <div class="content">
            <a href="service1.html">Innovative Tech Solutions</a>
            <div class="space16"></div>
            <p>We collaborate closely with to understand your unique goals, market position, and challenges craft a strategic plan tailored.</p>
            <div class="space24"></div>
            <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== SERVICE AREA ENDS =======-->
<div class="space100 d-lg-block d-none"></div>
<div class="space80 d-lg-block d-none"></div>
<!--===== WORK AREA STARTS =======-->
<div class="project12-section-area sp1">
  <div class="container">
    <div class="row">
      <div class="col-lg-7 m-auto">
        <div class="project-header heading18 text-center space-margin60">
          <h5 data-aos="fade-left" data-aos-duration="800">Projects</h5>
          <div class="space16"></div>
          <h2 class="text-anime-style-3">Business Evolution Projects</h2>
        </div>
      </div>
    </div>
    <div class="row">
      <div class="col-lg-12">
        <div class="project12-slider-area owl-carousel">
          <div class="project12-boxarea">
            <div class="img1">
              <img src="assets/img/all-images/new-img/project-img1-h12.png" alt="">
            </div>
            <div class="content-area">
              <p>Consulting Agency</p>
              <div class="space16"></div>
              <a href="case-single.html" class="head">Revitalizing Business Strategies</a>
              <div class="space16"></div>
              <p>Our approach combines industry insights, data-driven analysis, and innovative think  to develop actionable strategies that drive.</p>
              <div class="space24"></div>
              <a href="case-single.html" class="readmore">View Projects <i class="fa-solid fa-angle-right"></i></a>
            </div>
          </div>

          <div class="project12-boxarea">
            <div class="img1">
              <img src="assets/img/all-images/new-img/project-img2-h12.png" alt="">
            </div>
            <div class="content-area">
              <p>Consulting Agency</p>
              <div class="space16"></div>
              <a href="case-single.html" class="head">Revitalizing Business Strategies</a>
              <div class="space16"></div>
              <p>Our approach combines industry insights, data-driven analysis, and innovative think  to develop actionable strategies that drive.</p>
              <div class="space24"></div>
              <a href="case-single.html" class="readmore">View Projects <i class="fa-solid fa-angle-right"></i></a>
            </div>
          </div>

          <div class="project12-boxarea">
            <div class="img1">
              <img src="assets/img/all-images/new-img/project-img3-h12.png" alt="">
            </div>
            <div class="content-area">
              <p>Consulting Agency</p>
              <div class="space16"></div>
              <a href="case-single.html" class="head">Revitalizing Business Strategies</a>
              <div class="space16"></div>
              <p>Our approach combines industry insights, data-driven analysis, and innovative think  to develop actionable strategies that drive.</p>
              <div class="space24"></div>
              <a href="case-single.html" class="readmore">View Projects <i class="fa-solid fa-angle-right"></i></a>
            </div>
          </div>
          
          <div class="project12-boxarea">
            <div class="img1">
              <img src="assets/img/all-images/new-img/project-img3-h12.png" alt="">
            </div>
            <div class="content-area">
              <p>Consulting Agency</p>
              <div class="space16"></div>
              <a href="case-single.html" class="head">Revitalizing Business Strategies</a>
              <div class="space16"></div>
              <p>Our approach combines industry insights, data-driven analysis, and innovative think  to develop actionable strategies that drive.</p>
              <div class="space24"></div>
              <a href="case-single.html" class="readmore">View Projects <i class="fa-solid fa-angle-right"></i></a>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== WORK AREA ENDS =======-->

<!--===== TESTIMONIAL AREA STARTS =======-->
<div class="testimonial12-section-area sp1">
  <div class="container">
    <div class="row align-items-center">
      <div class="col-lg-6">
        <div class="testimonial12-boxarea-vertical">
          <div class="testimonial-boxarea">
            <img src="assets/img/icons/quito7.svg" alt="">
            <div class="space32"></div>
            <p>“We take pride in the success stories of our clients. Our commitment to delivering exceptional is reflected their feedback experiences. From enhanced operational efficiency to breakthrough market strategies.”</p>
            <div class="space32"></div>
            <div class="name-ara">
              <div class="text">
                <a href="#">Sarah L.</a>
                <ul>
                  <li><i class="fa-solid fa-star"></i></li>
                  <li><i class="fa-solid fa-star"></i></li>
                  <li><i class="fa-solid fa-star"></i></li>
                  <li><i class="fa-solid fa-star"></i></li>
                  <li><i class="fa-solid fa-star"></i></li>
                </ul>
              </div>
            <img src="assets/img/icons/google.svg" alt="">
            </div>
          </div>

          <div class="testimonial-boxarea">
            <img src="assets/img/icons/quito7.svg" alt="">
            <div class="space32"></div>
            <p>“We take pride in the success stories of our clients. Our commitment to delivering exceptional is reflected their feedback experiences. From enhanced operational efficiency to breakthrough market strategies.”</p>
            <div class="space32"></div>
            <div class="name-ara">
              <div class="text">
                <a href="#">Sarah L.</a>
                <ul>
                  <li><i class="fa-solid fa-star"></i></li>
                  <li><i class="fa-solid fa-star"></i></li>
                  <li><i class="fa-solid fa-star"></i></li>
                  <li><i class="fa-solid fa-star"></i></li>
                  <li><i class="fa-solid fa-star"></i></li>
                </ul>
              </div>
            <img src="assets/img/icons/google.svg" alt="">
            </div>
          </div>

          <div class="testimonial-boxarea">
            <img src="assets/img/icons/quito7.svg" alt="">
            <div class="space32"></div>
            <p>“We take pride in the success stories of our clients. Our commitment to delivering exceptional is reflected their feedback experiences. From enhanced operational efficiency to breakthrough market strategies.”</p>
            <div class="space32"></div>
            <div class="name-ara">
              <div class="text">
                <a href="#">Sarah L.</a>
                <ul>
                  <li><i class="fa-solid fa-star"></i></li>
                  <li><i class="fa-solid fa-star"></i></li>
                  <li><i class="fa-solid fa-star"></i></li>
                  <li><i class="fa-solid fa-star"></i></li>
                  <li><i class="fa-solid fa-star"></i></li>
                </ul>
              </div>
            <img src="assets/img/icons/google.svg" alt="">
            </div>
          </div>
        </div>
      </div>
      <div class="col-lg-1"></div>
      <div class="col-lg-5">
        <div class="testimonial-haeder heading18">
          <h5 data-aos="fade-left" data-aos-duration="800">Testimonial</h5>
          <div class="space16"></div>
          <h2 class="text-anime-style-3">Transformation That Speak for Themselves</h2>
          <div class="space20"></div>
          <p data-aos="fade-left" data-aos-duration="1000">Their testimonials not only showcase our dedication but also <br class="d-lg-block d-none"> illustrate the real-world benefits of partnering with.</p>
          <div class="space32"></div>
          <div class="btn-area1" data-aos="fade-left" data-aos-duration="1200">
            <a href="#" class="header-btn20">Get It Know <i class="fa-solid fa-angle-right"></i></a>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== TESTIMONIAL AREA ENDS =======-->

<!--===== TEAM AREA STARTS =======-->
<div class="team12-section-area sp2">
    <div class="container">
        <div class="row">
            <div class="col-lg-7 m-auto">
                <div class="team-header text-center heading18 space-margin60">
                    <h5><img src="assets/img/icons/logo-icon9.svg" alt=""> Our Team</h5>
                    <div class="space16"></div>
                    <h2 class="text-anime-style-3">Comprehensive Consulting</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="800">
                <div class="team12-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/team-img1-h12.png" alt="">
                    </div>
                    <div class="content-area">
                        <div class="text">
                            <a href="team.html">Stella Bradtke</a>
                            <div class="space12"></div>
                            <p>Digital Marketing Officer</p>
                        </div>
  
                    </div>
                    <ul>
                      <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                      <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
                      <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>                      
                      <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                    </ul>
                </div>
            </div>

            <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
              <div class="team12-boxarea">
                  <div class="img1">
                    <img src="assets/img/all-images/new-img/team-img2-h12.png" alt="">
                  </div>
                  <div class="content-area">
                      <div class="text">
                          <a href="team.html">Dominic Jones</a>
                          <div class="space12"></div>
                          <p>Digital Marketing Officer</p>
                      </div>

                  </div>
                  <ul>
                    <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                    <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
                    <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>                      
                    <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                  </ul>
              </div>
          </div>

          <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
            <div class="team12-boxarea">
                <div class="img1">
                    <img src="assets/img/all-images/new-img/team-img3-h12.png" alt="">
                </div>
                <div class="content-area">
                    <div class="text">
                        <a href="team.html">Ellen Blanda</a>
                        <div class="space12"></div>
                        <p>Digital Marketing Officer</p>
                    </div>

                </div>
                <ul>
                  <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                  <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
                  <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>                      
                  <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                </ul>
            </div>
        </div>

        <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
            <div class="team12-boxarea">
                <div class="img1">
                    <img src="assets/img/all-images/new-img/team-img4-h12.png" alt="">
                </div>
                <div class="content-area">
                    <div class="text">
                        <a href="team.html">Craig Purdy</a>
                        <div class="space12"></div>
                        <p>Digital Marketing Officer</p>
                    </div>

                </div>
                <ul>
                  <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                  <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
                  <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>                      
                  <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                </ul>
            </div>
        </div>
        </div>
    </div>
</div>
<!--===== TEAM AREA ENDS =======-->

<!--===== CONTACT AREA STARTS =======-->
<div class="contact12-section-area sp6">
    <div class="container">
      <div class="row">
        <div class="col-lg-6 m-auto">
          <div class="contact-header-area text-center heading18 space-margin60">
            <h5><img src="assets/img/icons/logo-icon9.svg" alt="">Contact Us</h5>
            <div class="space16"></div>
            <h2 class="text-anime-style-3">We’d Love to Hear From You</h2>
            <div class="space20"></div>
            <p>Whether you're interested in learning more about our services, need assistance with a current project, or simply want to discuss how. </p>
          </div>
        </div>
      </div>
      <div class="row">
        <div class="col-lg-5" data-aos="zoom-out" data-aos-duration="1000">
          <div class="contact-info-area">
            <h3>Contact Info</h3>
            <p>We're here to help! If you have any questions or would like to discuss how our SEO and digital marketing services can benefit your business,</p>
            <div class="space32"></div>
            <div class="contact-auhtor-box">
              <div class="icons">
                <img src="assets/img/icons/location2.svg" alt="">
              </div>
              <div class="content">
                <h4>Our Location</h4>
                <a href="#">8708 Technology Forest Pl Suite <br class="d-lg-block d-none"> 125 -G, The Woodlands, TX 773</a>
              </div>
            </div>
            <div class="space40"></div>
            <div class="contact-auhtor-box">
              <div class="icons">
                <img src="assets/img/icons/phone2.svg" alt="">
              </div>
              <div class="content">
                <h4>Phone Number</h4>
                <a href="tel:123-456-7890">123-456-7890 <br>
                  123-456-7890</a>
              </div>
            </div>
            <div class="space40"></div>
            <div class="contact-auhtor-box">
              <div class="icons">
                <img src="assets/img/icons/email2.svg" alt="">
              </div>
              <div class="content">
                <h4>Email Address</h4>
                <a href="mailto:infoseoc@.gmail.com">infoseoc@.gmail.com <br>
                infoseoc@.gmail.com</a>
              </div>
            </div>
          </div>
        </div>
        <div class="col-lg-7" data-aos="zoom-out" data-aos-duration="1200">
          <div class="contact-boxarea">
             <h3>Get In Touch</h3>
             <p>We're here to help! If you have any questions or would like to discuss <br class="d-lg-block d-none"> how our SEO and digital marketing services can benefit your business,</p>
             <form action="https://api.web3forms.com/submit" method="POST">
              <div class="row">
                <div class="col-lg-6">
                  <div class="input-area">
                    <input type="text" placeholder="First Name" required>
                  </div>
                </div>
                <div class="col-lg-6">
                  <div class="input-area">
                    <input type="text" placeholder="Last Name" required>
                  </div>
                </div>
                <div class="col-lg-6">
                  <div class="input-area">
                    <input type="email" placeholder="Email Address" required>
                  </div>
                </div>
  
                <div class="col-lg-6">
                  <div class="input-area">
                    <input type="number" placeholder="Phone Number" required>
                  </div>
                </div>
                <div class="col-lg-12">
                  <div class="input-area">
                    <select name="country" id="country" class="country-area nice-select6">
                      <option value="1" data-display="Service Type">Service Type</option>
                      <option value="">Belgium</option>
                      <option value="">Brezil</option>
                      <option value="">Argentina</option>
                      <option value="">Bangladesh</option>
                      <option value="">Germany</option>
                    </select>
                  </div>
                </div>
                <div class="col-lg-12">
                  <div class="input-area">
                    <textarea placeholder="Your Message" required></textarea>
                  </div>
                </div>
                <div class="col-lg-12">
                  <div class="input-area">
                    <button class="header-btn20">Get to Know  <i class="fa-solid fa-angle-right"></i></button>
                  </div>
                </div>
               </div>
             </form>
          </div>
        </div>
      </div>
    </div>
  </div>
<!--===== CONTACT AREA ENDS =======-->

<!--===== BLOG AREA STARTS =======-->
<div class="blog12-section-area sp2">
    <div class="container">
        <div class="row">
            <div class="col-lg-6 m-auto">
                <div class="blog-header heading18 space-margin60 text-center">
                    <h5><img src="assets/img/icons/logo-icon9.svg" alt=""> Our Blog</h5>
                    <div class="space24"></div>
                    <h2 class="text-anime-style-3">Our Latest Blog & News</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
                <div class="blog12-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/blog-img14-h11.png" alt="">
                    </div>
                    <div class="content-area">
                        <ul>
                            <li><a href="#"><i class="fa-regular fa-calendar-days"></i> 8 December 2024</a></li>
                            <li style="margin-left: 16px;"><a href="#"><i class="fa-regular fa-user"></i> Alex Carey</a></li>
                        </ul>
                        <div class="space16"></div>
                        <a href="blog-single.html" class="head">Stay Ahead with Expert Insight & Industry Trends</a>
                        <div class="space12"></div>
                        <p>Discover actionable strategies, thought leadership, and the latest development.</p>
                        <div class="space24"></div>
                        <a href="blog-single.html" class="readmore">learn more <span><i class="fa-solid fa-angle-right"></i></span></a>
                    </div>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                <div class="blog12-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/blog-img15-h11.png" alt="">
                    </div>
                    <div class="content-area">
                        <ul>
                            <li><a href="#"><i class="fa-regular fa-calendar-days"></i> 8 December 2024</a></li>
                            <li style="margin-left: 16px;"><a href="#"><i class="fa-regular fa-user"></i> Alex Carey</a></li>
                        </ul>
                        <div class="space16"></div>
                        <a href="blog-single.html" class="head">Unlocking Business Potential: Expert Insights & Strategies</a>
                        <div class="space12"></div>
                        <p>Explore our blog for the latest insights, innovative strategies, and practical tips.</p>
                        <div class="space24"></div>
                        <a href="blog-single.html" class="readmore">learn more <span><i class="fa-solid fa-angle-right"></i></span></a>
                    </div>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
                <div class="blog12-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/blog-img16-h11.png" alt="">
                    </div>
                    <div class="content-area">
                        <ul>
                            <li><a href="#"><i class="fa-regular fa-calendar-days"></i> 8 December 2024</a></li>
                            <li style="margin-left: 16px;"><a href="#"><i class="fa-regular fa-user"></i> Alex Carey</a></li>
                        </ul>
                        <div class="space16"></div>
                        <a href="blog-single.html" class="head">Explore our latest articles for actionable strategies, industry</a>
                        <div class="space12"></div>
                        <p>This heading aims to highlight the value of your blog content and encourage.</p>
                        <div class="space24"></div>
                        <a href="blog-single.html" class="readmore">learn more <span><i class="fa-solid fa-angle-right"></i></span></a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== BLOG AREA ENDS =======-->

<!--===== CTA AREA STARTS =======-->
<div class="cta12-section-area sp4">
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-5">
                <div class="cta-header">
                    <h2 class="text-anime-style-3">Ready To Power Up Your Savings And Reliability?</h2>
                    <div class="space32"></div>
                    <form>
                        <input type="text" placeholder="Your Email Address">
                        <button type="submit" class="header-btn20">Subscribe <i class="fa-solid fa-angle-right"></i></button>
                    </form>
                </div>
            </div>
            <div class="col-lg-1"></div>
            <div class="col-lg-3 col-md-6">
                <div class="cta-box">
                    <div class="icon">
                        <img src="assets/img/icons/phone5.svg" alt="">
                    </div>
                    <div class="text">
                        <p>Call Us 24/7</p>
                        <div class="space14"></div>
                        <a href="tel:+1234567890"> +123 456 7890</a>
                    </div>
                </div>
            </div>

            <div class="col-lg-3 col-md-6">
                <div class="space30 d-md-none d-block"></div>
                <div class="cta-box">
                    <div class="icon">
                        <img src="assets/img/icons/email5.svg" alt="">
                    </div>
                    <div class="text">
                        <p>Mail Us Anytime</p>
                        <div class="space14"></div>
                        <a href="mailto:SEOC@gmail.com">SEOC@gmail.com</a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== CTA AREA ENDS =======-->

<!--===== FOOTER AREA STARTS =======-->
<div class="footer12-section-area">
  <div class="container">
    <div class="row">
        <div class="col-lg-3 col-md-6">
            <div class="footer-log-area">
                <img src="assets/img/logo/logo13.png" alt="">
                <div class="space24"></div>
                <p>Our goal is to demystify the process, address your concerns, and empower you with the knowledge to embark.</p>
                <div class="space24"></div>
                <ul>
                    <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                    <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
                    <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                    <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
                </ul>
            </div>
        </div>
        <div class="col-lg-3 col-md-6">
            <div class="space30 d-md-none d-block"></div>
            <div class="footer-content-area footer1">
                <h3>Quick Links</h3>
                <ul>
                    <li><a href="about.html">About Us</a></li>
                    <li><a href="service1.html">Our Services</a></li>
                    <li><a href="service2.html">Our Solution</a></li>
                    <li><a href="blog.html">Our Blog</a></li>
                    <li><a href="contact.html">Contact Us</a></li>
                </ul>
            </div>
        </div>
        <div class="col-lg-3 col-md-6">
            <div class="space30 d-lg-none d-block"></div>
            <div class="footer-content-area">
                <h3>Our Services</h3>
                <ul>
                    <li><a href="about.html">Accounting Finance</a></li>
                    <li><a href="service1.html">Business Consulting</a></li>
                    <li><a href="service2.html">Technology Services</a></li>
                    <li><a href="blog.html">Logistics Services</a></li>
                    <li><a href="contact.html">Front Line Support</a></li>
                </ul>
            </div>
        </div>
        <div class="col-lg-3 col-md-6">
            <div class="space30 d-lg-none d-block"></div>
            <div class="footer-contact-area">
                <h3>Contact Us</h3>
                <div class="icons-area">
                    <div class="icons">
                        <i class="fa-solid fa-phone-volume"></i>
                    </div>
                    <div class="text">
                        <a href="tel:+11234567890">+1 123 456 7890</a>
                    </div>
                </div>

                <div class="icons-area">
                    <div class="icons">
                        <i class="fa-solid fa-location-dot"></i>
                    </div>
                    <div class="text">
                        <a href="tel:+11234567890">421 Allen, Mexico 4233</a>
                    </div>
                </div>

                <div class="icons-area">
                    <div class="icons">
                        <i class="fa-solid fa-envelope"></i>
                    </div>
                    <div class="text">
                        <a href="mailto:seocstaffngagency@com">seocstaffngagency@com</a>
                    </div>
                </div>

                <div class="icons-area">
                    <div class="icons">
                        <i class="fa-solid fa-globe"></i>
                    </div>
                    <div class="text">
                        <a href="mailto:seocstaffngagency@com">seocstaffngagency@com</a>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="space80 d-lg-block d-none"></div>
    <div class="space40 d-lg-none d-block"></div>
    <div class="row">
      <div class="col-lg-12">
        <div class="copyright-area">
          <div class="pera">
            <p>ⓒCopyright 2024 SEOC . All rights reserved</p>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== FOOTER AREA ENDS =======-->


<!--===== JS SCRIPT LINK =======-->
<script src="assets/js/plugins/bootstrap.min.js"></script>
<script src="assets/js/plugins/fontawesome.js"></script>
<script src="assets/js/plugins/aos.js"></script>
<script src="assets/js/plugins/counter.js"></script>
<script src="assets/js/plugins/gsap.min.js"></script>
<script src="assets/js/plugins/ScrollTrigger.min.js"></script>
<script src="assets/js/plugins/Splitetext.js"></script>
<script src="assets/js/plugins/sidebar.js"></script>
<script src="assets/js/plugins/magnific-popup.js"></script>
<script src="assets/js/plugins/mobilemenu.js"></script>
<script src="assets/js/plugins/owlcarousel.min.js"></script>
<script src="assets/js/plugins/gsap-animation.js"></script>
<script src="assets/js/plugins/nice-select.js"></script>
<script src="assets/js/plugins/waypoints.js"></script>
<script src="assets/js/plugins/slick-slider.js"></script>
<script src="assets/js/plugins/circle-progress.js"></script>
<script src="assets/js/main.js"></script>

</body>

<!-- Mirrored from seoc-html-v2.vercel.app/index12.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:40:44 GMT -->
</html>